==> gi-assets-algorithm-2.2.4.tgz: package/es/InfoDetection/Component.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { detectAllCycles } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { List } from 'antd';
import React, { useState } from 'react';
import DegreeScatter from './DegreeScatter';
import './index.less';
var InfoDetection = function InfoDetection() {
  var _useContext = useContext(),
    data = _useContext.data,
    graph = _useContext.graph;
  console.log('InfoDetection HAS GRAPH', graph && !graph.destroyed);
  var _useState = useState([]),
    _useState2 = _slicedToArray(_useState, 2),
    isolateNodes = _useState2[0],
    setIsolateNodes = _useState2[1];
  var _useState3 = useState([]),
    _useState4 = _slicedToArray(_useState3, 2),
    circles = _useState4[0],
    setCircles = _useState4[1];
  var _useState5 = useState(false),
    _useState6 = _slicedToArray(_useState5, 2),
    selectedIsolate = _useState6[0],
    setSelectedIsolate = _useState6[1];
  var _useState7 = useState(false),
    _useState8 = _slicedToArray(_useState7, 2),
    selectedCircle = _useState8[0],
    setSelectedCircle = _useState8[1];
  var _useState9 = useState(new Map()),
    _useState10 = _slicedToArray(_useState9, 2),
    inDegree = _useState10[0],
    setInDegree = _useState10[1];
  var _useState11 = useState(new Map()),
    _useState12 = _slicedToArray(_useState11, 2),
    outDegree = _useState12[0],
    setOutDegree = _useState12[1];
  var _useState13 = useState(new Map()),
    _useState14 = _slicedToArray(_useState13, 2),
    totalDegree = _useState14[0],
    setTotalDegree = _useState14[1];
  React.useEffect(function () {
    var isolateNodes = data.nodes.filter(function (item) {
      var node = graph.findById(item.id);
      return node.getEdges().length === 0;
    });
    var circles = detectAllCycles(data, false);
    // const pageRankRes = pageRank(data);
    // const totalPageRank = Object.keys(pageRankRes).reduce((acc, cur) => {
    //     return acc + pageRankRes[cur]
    // }, 0)
    // const avgPageRank = totalPageRank / Object.keys(pageRankRes).length;
    // const avgDegree = data.edges.length * 2 / data.nodes.length;
    var inDegreeCalc = new Map();
    var outDegreeCalc = new Map();
    var totalDegreeCalc = new Map();
    data.nodes.forEach(function (node) {
      var nodeItem = graph.findById(node.id);
      var edges = nodeItem.getEdges();
      // 总度数为节点相连的边的数量
      var total = edges.length;
      var inD = 0;
      var outD = 0;
      edges.forEach(function (edge) {
        var _edge$getModel = edge.getModel(),
          source = _edge$getModel.source;
        if (source === node.id) {
          outD++;
        } else {
          inD++;
        }
      });
      inDegreeCalc.set(inD, inDegreeCalc.has(inD) ? inDegreeCalc.get(inD) + 1 : 1);
      outDegreeCalc.set(outD, outDegreeCalc.has(outD) ? outDegreeCalc.get(outD) + 1 : 1);
      totalDegreeCalc.set(total, totalDegreeCalc.has(total) ? totalDegreeCalc.get(total) + 1 : 1);
    });
    setIsolateNodes(isolateNodes);
    setCircles(circles);
    setInDegree(inDegreeCalc);
    setOutDegree(outDegreeCalc);
    setTotalDegree(totalDegreeCalc);
  }, [data]);
  React.useEffect(function () {
    data.nodes.forEach(function (item) {
      graph.findById(item.id) && graph.setItemState(item.id, 'active', false);
    });
    data.edges.forEach(function (item) {
      graph.findById(item.id) && graph.setItemState(item.id, 'active', false);
    });
    if (selectedIsolate) {
      isolateNodes.forEach(function (node) {
        graph.findById(node.id) && graph.setItemState(node.id, 'active', true);
      });
    }
    if (selectedCircle) {
      circles.forEach(function (circle) {
        var start = Object.keys(circle)[0];
        // 遍历环 高亮环上所有的节点和边
        var cur = start;
        var _loop = function _loop() {
          graph.setItemState(cur, 'active', true);
          var next = circle[cur].id;
          var item = graph.findById(cur);
          var edges = item.getEdges();
          edges.forEach(function (edge) {
            var _edge$getModel2 = edge.getModel(),
              source = _edge$getModel2.source,
              target = _edge$getModel2.target,
              id = _edge$getModel2.id;
            if (source === cur && target == next || source == next && target === cur) {
              graph.setItemState(edge.getID(), 'active', true);
            }
          });
          cur = next;
        };
        do {
          _loop();
        } while (cur !== start);
      });
    }
  }, [selectedIsolate, selectedCircle]);
  return /*#__PURE__*/React.createElement("div", {
    className: "gi-info-detection"
  }, /*#__PURE__*/React.createElement(List, null, /*#__PURE__*/React.createElement(List.Item, {
    key: "isolate",
    extra: /*#__PURE__*/React.createElement("div", null, isolateNodes.length),
    onClick: function onClick() {
      return setSelectedIsolate(function (old) {
        return !old;
      });
    },
    style: {
      border: selectedIsolate ? 'solid blue 1px' : 'none'
    }
  }, "\u5B64\u7ACB\u70B9"), /*#__PURE__*/React.createElement(List.Item, {
    key: "circle",
    extra: /*#__PURE__*/React.createElement("div", null, circles.length),
    onClick: function onClick() {
      return setSelectedCircle(function (old) {
        return !old;
      });
    },
    style: {
      border: selectedCircle ? 'solid blue 1px' : 'none'
    }
  }, "\u73AF")), /*#__PURE__*/React.createElement(DegreeScatter, {
    degree: {
      inDegree: inDegree,
      outDegree: outDegree,
      totalDegree: totalDegree
    }
  }));
};
export default InfoDetection;

==> gi-assets-algorithm-2.3.6.tgz: package/es/InfoDetection/Component.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { detectAllCycles } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { List } from 'antd';
import React, { useState } from 'react';
import DegreeScatter from './DegreeScatter';
import './index.less';
import $i18n from '../i18n';
var InfoDetection = function InfoDetection() {
  var _useContext = useContext(),
    data = _useContext.data,
    graph = _useContext.graph;
  console.log('InfoDetection HAS GRAPH', graph && !graph.destroyed);
  var _useState = useState([]),
    _useState2 = _slicedToArray(_useState, 2),
    isolateNodes = _useState2[0],
    setIsolateNodes = _useState2[1];
  var _useState3 = useState([]),
    _useState4 = _slicedToArray(_useState3, 2),
    circles = _useState4[0],
    setCircles = _useState4[1];
  var _useState5 = useState(false),
    _useState6 = _slicedToArray(_useState5, 2),
    selectedIsolate = _useState6[0],
    setSelectedIsolate = _useState6[1];
  var _useState7 = useState(false),
    _useState8 = _slicedToArray(_useState7, 2),
    selectedCircle = _useState8[0],
    setSelectedCircle = _useState8[1];
  var _useState9 = useState(new Map()),
    _useState10 = _slicedToArray(_useState9, 2),
    inDegree = _useState10[0],
    setInDegree = _useState10[1];
  var _useState11 = useState(new Map()),
    _useState12 = _slicedToArray(_useState11, 2),
    outDegree = _useState12[0],
    setOutDegree = _useState12[1];
  var _useState13 = useState(new Map()),
    _useState14 = _slicedToArray(_useState13, 2),
    totalDegree = _useState14[0],
    setTotalDegree = _useState14[1];
  React.useEffect(function () {
    var isolateNodes = data.nodes.filter(function (item) {
      var node = graph.findById(item.id);
      return node.getEdges().length === 0;
    });
    var circles = detectAllCycles(data, false);
    // const pageRankRes = pageRank(data);
    // const totalPageRank = Object.keys(pageRankRes).reduce((acc, cur) => {
    //     return acc + pageRankRes[cur]
    // }, 0)
    // const avgPageRank = totalPageRank / Object.keys(pageRankRes).length;
    // const avgDegree = data.edges.length * 2 / data.nodes.length;
    var inDegreeCalc = new Map();
    var outDegreeCalc = new Map();
    var totalDegreeCalc = new Map();
    data.nodes.forEach(function (node) {
      var nodeItem = graph.findById(node.id);
      var edges = nodeItem.getEdges();
      // 总度数为节点相连的边的数量
      var total = edges.length;
      var inD = 0;
      var outD = 0;
      edges.forEach(function (edge) {
        var _edge$getModel = edge.getModel(),
          source = _edge$getModel.source;
        if (source === node.id) {
          outD++;
        } else {
          inD++;
        }
      });
      inDegreeCalc.set(inD, inDegreeCalc.has(inD) ? inDegreeCalc.get(inD) + 1 : 1);
      outDegreeCalc.set(outD, outDegreeCalc.has(outD) ? outDegreeCalc.get(outD) + 1 : 1);
      totalDegreeCalc.set(total, totalDegreeCalc.has(total) ? totalDegreeCalc.get(total) + 1 : 1);
    });
    setIsolateNodes(isolateNodes);
    setCircles(circles);
    setInDegree(inDegreeCalc);
    setOutDegree(outDegreeCalc);
    setTotalDegree(totalDegreeCalc);
  }, [data]);
  React.useEffect(function () {
    data.nodes.forEach(function (item) {
      graph.findById(item.id) && graph.setItemState(item.id, 'active', false);
    });
    data.edges.forEach(function (item) {
      graph.findById(item.id) && graph.setItemState(item.id, 'active', false);
    });
    if (selectedIsolate) {
      isolateNodes.forEach(function (node) {
        graph.findById(node.id) && graph.setItemState(node.id, 'active', true);
      });
    }
    if (selectedCircle) {
      circles.forEach(function (circle) {
        var start = Object.keys(circle)[0];
        // 遍历环 高亮环上所有的节点和边
        var cur = start;
        var _loop = function _loop() {
          graph.setItemState(cur, 'active', true);
          var next = circle[cur].id;
          var item = graph.findById(cur);
          var edges = item.getEdges();
          edges.forEach(function (edge) {
            var _edge$getModel2 = edge.getModel(),
              source = _edge$getModel2.source,
              target = _edge$getModel2.target,
              id = _edge$getModel2.id;
            if (source === cur && target == next || source == next && target === cur) {
              graph.setItemState(edge.getID(), 'active', true);
            }
          });
          cur = next;
        };
        do {
          _loop();
        } while (cur !== start);
      });
    }
  }, [selectedIsolate, selectedCircle]);
  return /*#__PURE__*/React.createElement("div", {
    className: "gi-info-detection"
  }, /*#__PURE__*/React.createElement(List, null, /*#__PURE__*/React.createElement(List.Item, {
    key: "isolate",
    extra: /*#__PURE__*/React.createElement("div", null, isolateNodes.length),
    onClick: function onClick() {
      return setSelectedIsolate(function (old) {
        return !old;
      });
    },
    style: {
      border: selectedIsolate ? 'solid blue 1px' : 'none'
    }
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.Component.IsolatedPoint',
    dm: '孤立点'
  })), /*#__PURE__*/React.createElement(List.Item, {
    key: "circle",
    extra: /*#__PURE__*/React.createElement("div", null, circles.length),
    onClick: function onClick() {
      return setSelectedCircle(function (old) {
        return !old;
      });
    },
    style: {
      border: selectedCircle ? 'solid blue 1px' : 'none'
    }
  }, $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.Component.Ring',
    dm: '环'
  }))), /*#__PURE__*/React.createElement(DegreeScatter, {
    degree: {
      inDegree: inDegree,
      outDegree: outDegree,
      totalDegree: totalDegree
    }
  }));
};
export default InfoDetection;
